@@ -1738,12 +1738,14 @@ class Tablebases(object):
                 board.push(move)
                 try:
                     v = -self.probe_dtz(board)
+
+                    if v > 0 and v + 1 < best:
+                        if v == 1 and board.is_checkmate():
+                            v = 0
+                        best = v + 1
                 finally:
                     board.pop()
 
-                if v > 0 and v + 1 < best:
-                    best = v + 1
-
             return best
         else:
             best = -1
